========================
Contributing to Alchimia
========================

As an open source project, Alchimia welcomes contributions of many forms.

Examples of contributions include:

* Code patches
* Documentation improvements
* Bug reports and patch reviews

Extensive contribution guidelines are available in the repository at
``docs/contributing.rst``

We welcome pull requests and tickets on `github`_!

.. _`github`: https://github.com/alex/alchimia
